/*
Copyright 2020 The Jenkins X Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package fake

import (
	"context"

	v1 "github.com/jenkins-x/jx-api/v4/pkg/apis/jenkins.io/v1"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	labels "k8s.io/apimachinery/pkg/labels"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	testing "k8s.io/client-go/testing"
)

// FakeReleases implements ReleaseInterface
type FakeReleases struct {
	Fake *FakeJenkinsV1
	ns   string
}

var releasesResource = v1.SchemeGroupVersion.WithResource("releases")

var releasesKind = v1.SchemeGroupVersion.WithKind("Release")

// Get takes name of the release, and returns the corresponding release object, and an error if there is any.
func (c *FakeReleases) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.Release, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewGetAction(releasesResource, c.ns, name), &v1.Release{})

	if obj == nil {
		return nil, err
	}
	return obj.(*v1.Release), err
}

// List takes label and field selectors, and returns the list of Releases that match those selectors.
func (c *FakeReleases) List(ctx context.Context, opts metav1.ListOptions) (result *v1.ReleaseList, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewListAction(releasesResource, releasesKind, c.ns, opts), &v1.ReleaseList{})

	if obj == nil {
		return nil, err
	}

	label, _, _ := testing.ExtractFromListOptions(opts)
	if label == nil {
		label = labels.Everything()
	}
	list := &v1.ReleaseList{ListMeta: obj.(*v1.ReleaseList).ListMeta}
	for _, item := range obj.(*v1.ReleaseList).Items {
		if label.Matches(labels.Set(item.Labels)) {
			list.Items = append(list.Items, item)
		}
	}
	return list, err
}

// Watch returns a watch.Interface that watches the requested releases.
func (c *FakeReleases) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	return c.Fake.
		InvokesWatch(testing.NewWatchAction(releasesResource, c.ns, opts))

}

// Create takes the representation of a release and creates it.  Returns the server's representation of the release, and an error, if there is any.
func (c *FakeReleases) Create(ctx context.Context, release *v1.Release, opts metav1.CreateOptions) (result *v1.Release, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewCreateAction(releasesResource, c.ns, release), &v1.Release{})

	if obj == nil {
		return nil, err
	}
	return obj.(*v1.Release), err
}

// Update takes the representation of a release and updates it. Returns the server's representation of the release, and an error, if there is any.
func (c *FakeReleases) Update(ctx context.Context, release *v1.Release, opts metav1.UpdateOptions) (result *v1.Release, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateAction(releasesResource, c.ns, release), &v1.Release{})

	if obj == nil {
		return nil, err
	}
	return obj.(*v1.Release), err
}

// Delete takes name of the release and deletes it. Returns an error if one occurs.
func (c *FakeReleases) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	_, err := c.Fake.
		Invokes(testing.NewDeleteActionWithOptions(releasesResource, c.ns, name, opts), &v1.Release{})

	return err
}

// DeleteCollection deletes a collection of objects.
func (c *FakeReleases) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	action := testing.NewDeleteCollectionAction(releasesResource, c.ns, listOpts)

	_, err := c.Fake.Invokes(action, &v1.ReleaseList{})
	return err
}

// Patch applies the patch and returns the patched release.
func (c *FakeReleases) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Release, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceAction(releasesResource, c.ns, name, pt, data, subresources...), &v1.Release{})

	if obj == nil {
		return nil, err
	}
	return obj.(*v1.Release), err
}
